@@ -3,13 +3,17 @@
 """Download, open, and query ChEMBL through SQLite."""
 
 from .api import (  # noqa:F401
+    chemfp_load_fps,
     connect,
     cursor,
+    download_chemreps,
     download_extract_sqlite,
+    download_fps,
     download_sdf,
     download_sqlite,
+    get_chemreps_df,
+    get_substructure_library,
     latest,
     query,
-    get_substructure_library,
     supplier,
 )
